@@ -276,8 +276,8 @@ def getBetweenDay(begin_date: str, end_date: str) -> list:
         begin_date = datetime.datetime.strptime(begin_date, "%Y-%m-%d")
         end_date = datetime.datetime.strptime(end_date, "%Y-%m-%d")
     except:
-        begin_date = datetime.datetime.strptime(begin_date, "%Y-%m-%d %H:%M:%S")
-        end_date = datetime.datetime.strptime(end_date, "%Y-%m-%d %H:%M:%S")
+        begin_date = datetime.datetime.strptime(begin_date.split(' ')[0], "%Y-%m-%d")
+        end_date = datetime.datetime.strptime(end_date.split(' ')[0], "%Y-%m-%d")
     while begin_date <= end_date:
         date_str = begin_date.strftime("%Y-%m-%d")
         date_list.append(date_str)
